@@ -6,7 +6,7 @@ import subprocess
 from functools import partial
 from functools import reduce
 
-__version__ = '1.0.10'
+__version__ = '1.0.11'
 
 
 class B:
@@ -57,6 +57,12 @@ class Unique(B):
             yield item
 
 
+class ApplyInplace(B):
+    def __ror__(self, x):
+        self.f(x)
+        return x
+
+
 class ForEach(B):
     def __ror__(self, x):
         for e in x: self.f(e)
